#!/bin/bash

# Define color codes
GREEN='\e[32m'
BLUE='\e[34m'
YELLOW='\e[33m'
NC='\e[0m' # No Color

# Function for consistent log messages
log_success() { echo -e "${GREEN}[SUCCESS]${NC} $1"; }
log_info() { echo -e "${BLUE}[INFO]${NC} $1"; }
log_skip() { echo -e "${YELLOW}[SKIPPED]${NC} $1"; }

# Überprüfen, ob der .ssh-Ordner existiert, wenn nicht, erstelle ihn
if [ ! -d "$HOME/.ssh" ]; then
  mkdir -m 700 "$HOME/.ssh"
  log_success ".ssh-Verzeichnis wurde erstellt."
else
  log_info ".ssh-Verzeichnis existiert bereits."
fi

# Benutzer fragen, ob ein SSH-Key hinzugefügt werden soll
log_info "SSH-Public-Key hinzufügen? (Leerlassen zum Überspringen)"
read -p "> " user_input

# Nur fortfahren, wenn der Benutzer etwas eingegeben hat
if [ ! -z "$user_input" ]; then
  # Überprüfen, ob der Key bereits in authorized_keys vorhanden ist
  if grep -q "$user_input" "$HOME/.ssh/authorized_keys"; then
    log_info "Der SSH-Public-Key ist bereits vorhanden."
  else
    # Den eingegebenen Public Key in die authorized_keys-Datei speichern
    echo "$user_input" >> "$HOME/.ssh/authorized_keys"
    log_success "SSH-Public-Key wurde hinzugefügt."
  fi
else
  log_skip "SSH-Key Installation übersprungen."
fi

# Fragen, ob das System aktualisiert werden soll
log_info "System aktualisieren? (Y/n)"
read -p "> " update_input

# Überprüfen der Eingabe - Standardmäßig 'Y' bei Enter, sonst nur bei 'y' oder 'Y'
if [[ -z "$update_input" || "$update_input" =~ ^[Yy]$ ]]; then
    log_info "System wird aktualisiert..."
    apt update && apt upgrade -y
    log_success "System wurde erfolgreich aktualisiert."
else
    log_skip "System-Aktualisierung übersprungen."
fi
